@@ -8,8 +8,7 @@ from exchangelib import Message as Msg2, Account
 from bs4 import BeautifulSoup
 from logging import getLogger, WARNING
 
-log = lgetLogger(__name__)
-log.getLogger("exchangelib").setLevel(WARNING)
+getLogger("exchangelib").setLevel(WARNING)
 
 
 class E2M(Msg):
